@@ -1345,6 +1345,15 @@ class AMLPipelineHelper:
                     old_env_file_path, os.path.splitext(old_env_file_path)[0] + ".yaml"
                 )
 
+    def _recover_tenant_overrides(
+        self, override, yaml_to_be_recovered, keep_modified_files
+    ):
+        if override and yaml_to_be_recovered:
+            try:
+                self._recover_spec_yaml(yaml_to_be_recovered, keep_modified_files)
+            except BaseException as e:
+                log.error(f"An error occurred, recovery is not successful: {e}")
+
     ################
     ### MAIN/RUN ###
     ################
@@ -1414,14 +1423,23 @@ class AMLPipelineHelper:
 
     def run(self):
         """Run pipeline using arguments"""
+        # set logging level
+        if self.config.run.verbose:
+            logging.getLogger().setLevel(logging.DEBUG)
+
         # Log the telemetry information in the Azure Application Insights
-        telemetry_logger = TelemetryLogger(
-            enable_telemetry=not self.config.run.disable_telemetry
-        )
-        telemetry_logger.log_trace(
-            message=f"shrike.pipeline=={__version__}",
-            properties={"custom_dimensions": {"configuration": str(self.config)}},
-        )
+        try:
+            telemetry_logger = TelemetryLogger(
+                enable_telemetry=not self.config.run.disable_telemetry
+            )
+            telemetry_logger.log_trace(
+                message=f"shrike.pipeline=={__version__}",
+                properties={"custom_dimensions": {"configuration": str(self.config)}},
+            )
+        except Exception as ex:
+            log.debug(
+                f"Sending trace log messages to application insight is not successful. The exception message: {ex}"
+            )
 
         # Check whether the experiment name is valid
         self.validate_experiment_name(self.config.run.experiment_name)
@@ -1432,9 +1450,6 @@ class AMLPipelineHelper:
         log.info(f"azureml.core.VERSION = {azureml.core.VERSION}")
         self.connect()
 
-        if self.config.run.verbose:
-            logging.getLogger().setLevel(logging.DEBUG)
-
         pipeline_run = None
         if self.config.run.resume:
             if not self.config.run.pipeline_run_id:
@@ -1467,15 +1482,18 @@ class AMLPipelineHelper:
                             self.config.tenant_overrides.keep_modified_files
                         )
                     except BaseException as e:
-                        log.error(f"An error occured, override is not successful: {e}")
-
-            pipeline_run = self.build_and_submit_new_pipeline()
-
-            if override and yaml_to_be_recovered:
-                try:
-                    self._recover_spec_yaml(yaml_to_be_recovered, keep_modified_files)
-                except BaseException as e:
-                    log.error(f"An error occured, recovery is not successful: {e}")
+                        log.error(f"An error occurred, override is not successful: {e}")
+            try:
+                pipeline_run = self.build_and_submit_new_pipeline()
+            except BaseException as e:
+                log.error(f"An error {e} occurred during pipeline submission.")
+                if override:
+                    log.info("Now trying to recover overrides.")
+                self._recover_tenant_overrides(override, yaml_to_be_recovered, False)
+            else:
+                self._recover_tenant_overrides(
+                    override, yaml_to_be_recovered, keep_modified_files
+                )
 
         if not pipeline_run:
             # not submitting code, exit now
